import os
import openpyxl
import pickle
import numbers
import csv
import datetime
import json
from PyQt5.QtWidgets import QMainWindow, QToolBar, QFileDialog, QMessageBox, QListWidgetItem, QProgressDialog
from PyQt5.QtCore import Qt, QDate
from zhou_stattool.roomdata_window import Ui_MainWindow
from zhou_stattool.add_rule_window_main import AddRuleMainWindow


class RoomdataMainWindow(QMainWindow):

    DATETIME_FORMAT = '%Y/%m/%d %H:%M:%S'
    DATETIME_FORMAT_WITHOUT_SECOND = '%Y/%m/%d'

    def __init__(self):
        super(RoomdataMainWindow, self).__init__()
        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)
        self.add_toolbar()
        self.bind_actions()
        self.init_vars()

    def add_toolbar(self):
        self.toolbar = QToolBar()
        self.addToolBar(Qt.TopToolBarArea, self.toolbar)
        self.toolbar.addAction(self.ui.actionopen_file)
        self.toolbar.addAction(self.ui.actionopen_dir)

    def bind_actions(self):
        self.ui.actionopen_dir.triggered.connect(self.open_dir)
        self.ui.actionopen_file.triggered.connect(self.open_file)
        self.ui.add_rule_btn.clicked.connect(self.add_rule)
        self.ui.remove_rule_btn.clicked.connect(self.remove_rule)
        self.ui.edit_rule_btn.clicked.connect(self.edit_rule)
        self.ui.open_rule_btn.clicked.connect(self.open_rule)
        self.ui.save_rule_btn.clicked.connect(self.save_rule)
        self.ui.rules_widget.itemClicked.connect(self.rule_item_clicked)
        self.ui.start_process_btn.clicked.connect(self.start_process)

    def init_vars(self):
        self.opened_files = list()
        self.table_header = list()
        self.rule = list()
        self.ui.start_process_btn.setEnabled(False)
        today = datetime.datetime.today()
        tomorrow = datetime.datetime(today.year, today.month, today.day + 1)
        self.ui.start_date_edit.setDate(today)
        self.ui.end_date_edit.setDate(tomorrow)
        self.ui.start_date_edit.setCalendarPopup(True)
        self.ui.end_date_edit.setCalendarPopup(True)

    def open_dir(self, checked):
        file_dialog = QFileDialog(self)
        file_dialog.setFileMode(QFileDialog.DirectoryOnly)
        dir_name = file_dialog.getExistingDirectory()
        file_names = os.listdir(dir_name)
        for file_name in file_names:
            if not file_name.endswith('xlsx'):
                QMessageBox.critical(self, '错误', '文件夹中包含非表格文件', QMessageBox.Yes)
                return
        file_names = [os.path.join(dir_name, item) for item in file_names]
        self.opened_files = file_names
        self.show_opened_files()


    def open_file(self, checked):
        file_dialog = QFileDialog(self)
        file_dialog.setFileMode(QFileDialog.ExistingFiles)
        file_names = file_dialog.getOpenFileNames(filter='表格文件(*.xlsx)')[0]
        if file_names and len(file_names) > 0:
            self.opened_files = file_names
            self.show_opened_files()
        else:
            QMessageBox.critical(self, '错误', '请选择正确文件', QMessageBox.Yes)

    def check_file_headers(self):
        if not self.opened_files:
            return True, []
        wb = openpyxl.load_workbook(self.opened_files[0])
        sheet = wb['Sheet1']
        num_columns = sheet.max_column
        header = [sheet.cell(1, i).value.strip() for i in range(1, num_columns + 1)]
        for i in range(1, len(self.opened_files)):
            wb = openpyxl.load_workbook(self.opened_files[i])
            sheet = wb['Sheet1']
            if sheet.max_column != num_columns:
                return False, []
            for col in range(1, num_columns + 1):
                val = sheet.cell(1, col).value.strip()
                if val != header[col - 1]:
                    return False, []
        return True, header

    def show_opened_files(self):
        ret, header = self.check_file_headers()
        if ret and header:
            self.ui.opened_files_widget.clear()
            for file_name in self.opened_files:
                show_name = os.path.basename(file_name)
                self.ui.opened_files_widget.addItem(show_name)
            self.table_header = header
            self.ui.excel_header_widget.clear()
            for item in header:
                self.ui.excel_header_widget.addItem(item)
        else:
            self.opened_files.clear()
            self.ui.opened_files_widget.clear()
            QMessageBox.critical(self, '错误', '选择文件的表格头不一致', QMessageBox.Yes)

    def add_rule(self):
        if self.opened_files:
            self.add_rule_window = AddRuleMainWindow(self.table_header)
            self.add_rule_window.setWindowModality(Qt.ApplicationModal)
            ret = self.add_rule_window.exec_()
            if ret:
                name, indexes = self.add_rule_window.get_result()
                indexes = [item.row() for item in indexes]
                if not name or not indexes:
                    QMessageBox.critical(self, '错误', '请输入规则名并选择对应项', QMessageBox.Yes)
                else:
                    self.rule.append([name, [(i, self.table_header[i]) for i in indexes]])
                    self.refresh_rule_widget()
        else:
            QMessageBox.critical(self, '错误', '请先打开文件', QMessageBox.Yes)

    def remove_rule(self):
        selected_index = self.ui.rules_widget.selectedIndexes()
        if selected_index:
            selected_index = selected_index[0].row()
            self.ui.rule_detail_widget.clear()
            self.rule.pop(selected_index)
            self.refresh_rule_widget()

    def edit_rule(self):
        selected_index = self.ui.rules_widget.selectedIndexes()
        if selected_index:
            selected_index = selected_index[0].row()
            rule = self.rule[selected_index]
            self.add_rule_window = AddRuleMainWindow(self.table_header, rule[0], [rule[1][i][0] for i in range(len(rule[1]))])
            self.add_rule_window.setWindowModality(Qt.ApplicationModal)
            ret = self.add_rule_window.exec_()
            if ret:
                name, indexes = self.add_rule_window.get_result()
                indexes = [item.row() for item in indexes]
                try:
                    self.rule[selected_index][0] = name
                    self.rule[selected_index][1] = [(i, self.table_header[i]) for i in indexes]
                    self.refresh_rule_widget()
                except Exception as e:
                    print(e)


    def open_rule(self):
        if not self.opened_files:
            QMessageBox.critical(self, '错误', '请首先打开文件', QMessageBox.Yes)
        else:
            file_dialog = QFileDialog(self)
            file_dialog.setFileMode(QFileDialog.ExistingFile)
            file_name, _ = file_dialog.getOpenFileName(filter='规则(*.pkl)')
            if file_name:
                ret = self.open_and_check_rule_file(file_name)
                if not ret:
                    QMessageBox.critical(self, '错误', '所选文件不是规则文件或与所打开表格头不一致', QMessageBox.Yes)
                else:
                    self.refresh_rule_widget()

    def open_and_check_rule_file(self, file_path):
        with open(file_path, 'rb') as f:
            data = pickle.load(f)
        if not isinstance(data, list):
            return False
        for item in data:
            if not isinstance(item, list) or len(item) != 2 or not isinstance(item[0], str) or not isinstance(item[1], list):
                return False
            for it in item[1]:
                if not isinstance(it, tuple) or not isinstance(it[0], numbers.Number) or it[1] not in self.table_header:
                    return False
        self.rule = data
        return True

    def save_rule(self):
        if not self.rule:
            QMessageBox.critical(self, '错误', '请首先创建规则', QMessageBox.Yes)
        else:
            file_path, _ = QFileDialog.getSaveFileName(self, '保存规则', './', '规则文件(*.pkl)')
            if file_path:
                with open(file_path, 'wb') as f:
                    pickle.dump(self.rule, f)

    def refresh_rule_widget(self):
        self.ui.rule_detail_widget.clear()
        self.ui.rules_widget.clear()
        for rule in self.rule:
            self.ui.rules_widget.addItem(rule[0])
        if self.rule:
            self.ui.start_process_btn.setEnabled(True)

    def rule_item_clicked(self, item: QListWidgetItem):
        selected_index = self.ui.rules_widget.selectedIndexes()[0].row()
        data = self.rule[selected_index][1]
        self.ui.rule_detail_widget.clear()
        for item in data:
            self.ui.rule_detail_widget.addItem(item[1])

    def start_process(self):
        start_time = self.ui.start_date_edit.date()
        end_time = self.ui.end_date_edit.date()
        if start_time >= end_time:
            QMessageBox.critical(self, '错误', '结束日期要在开始日期之后', QMessageBox.Yes)
        else:
            csv_result = self.generate_csv()
            self.generate_score(csv_result)

    def generate_score(self, csv_result):
        total_num = [len(c) * len(self.rule) for c in csv_result]
        total_num = sum(total_num)
        count = 0
        progress = QProgressDialog(self)
        progress.setWindowTitle("正在处理")
        progress.setLabelText("正在生成结果")
        progress.setMinimumDuration(1)
        progress.setWindowModality(Qt.WindowModal)
        progress.setRange(0, total_num)
        dst_path = os.path.dirname(self.opened_files[0])
        for index, file_name in enumerate(self.opened_files):
            data = csv_result[index]
            result = {}
            for item in data:
                address = item['address']
                result[address] = {}
                for key, value in self.rule:
                    score_dict = {'满意': 0, '较满意': 0, '一般': 0, '不满意': 0, '很不满意': 0, '未接触': 0}
                    for _, name in value:
                        try:
                            d = item[name]
                        except KeyError as e:
                            print(file_name, name)
                        d = d.replace("'", "\"")
                        d = json.loads(d)
                        result[address]['样本量'] = sum(d.values())
                        for k, v in d.items():
                            if k in score_dict:
                                score_dict[k] += v
                    try:
                        score = 100 * (score_dict['满意'] + score_dict['较满意'] * 0.9 + score_dict['一般'] * 0.7 +
                                       score_dict['不满意'] * 0.4) / (
                                            score_dict['满意'] + score_dict['较满意'] + score_dict['一般'] + score_dict[
                                        '不满意'] + score_dict['很不满意'])
                    except ZeroDivisionError as e:
                        score = 0
                    result[address][key] = score
                    count += 1
                    progress.setValue(count)
            header = ['address'] + [item[0] for item in self.rule] + ['样本量']
            base_file_name = os.path.basename(self.opened_files[index])
            with open(os.path.join(dst_path, f"{base_file_name.split('.')[0]}_result.csv"), 'w', encoding='utf',
                      newline='\n') as f:
                writer = csv.DictWriter(f, fieldnames=header)
                writer.writeheader()
                for address, v in result.items():
                    v['address'] = address
                    writer.writerow(v)

    def generate_csv(self):
        dst_path = os.path.dirname(self.opened_files[0])
        sheets = [openpyxl.load_workbook(name)['Sheet1'] for name in self.opened_files]
        total_num = 0
        for sheet in sheets:
            total_num += (sheet.max_row - 1) * (len(self.table_header) - 9)
        progress = QProgressDialog(self)
        progress.setWindowTitle("正在处理")
        progress.setLabelText("正在生成csv")
        progress.setMinimumDuration(1)
        progress.setWindowModality(Qt.WindowModal)
        progress.setRange(0, total_num)
        count = 0
        final_result = []
        for index, sheet in enumerate(sheets):
            num_row = sheet.max_row
            num_column = sheet.max_column
            column_names = ['address']
            for col in range(10, num_column + 1):
                column_names.append(sheet.cell(1, col).value.strip())
            result = {}
            for row in range(2, num_row + 1):
                submit_date = sheet.cell(row, 2).value.strip()
                submit_date = datetime.datetime.strptime(submit_date, self.DATETIME_FORMAT)
                submit_date = QDate(submit_date.year, submit_date.month, submit_date.day)
                start_date = self.ui.start_date_edit.date()
                end_date = self.ui.end_date_edit.date()
                if submit_date < start_date or submit_date > end_date:
                    count += (len(self.table_header) - 9)
                    progress.setValue(count)
                    continue
                address = sheet.cell(row, 9).value.strip()
                if address not in result:
                    result[address] = {}
                for col in range(10, num_column + 1):
                    value = sheet.cell(row, col).value.strip()
                    if col not in result[address]:
                        result[address][col] = {'满意': 0, '较满意': 0, '一般': 0, '不满意': 0, '很不满意': 0,
                                                '未接触': 0}
                    if value in result[address][col].keys():
                        result[address][col][value] += 1
                    count += 1
                    progress.setValue(count)
            csv_result = []
            file_name = os.path.basename(self.opened_files[index])
            with open(os.path.join(dst_path, file_name.split('.')[0] + '.csv'), 'w', encoding='utf8') as f:
                writer = csv.DictWriter(f, column_names, lineterminator='\n')
                writer.writeheader()
                for address, data in result.items():
                    write_data = {}
                    write_data['address'] = address
                    for col in range(10, num_column + 1):
                        write_data[column_names[col - 9]] = str(result[address][col])
                    writer.writerow(write_data)
                    csv_result.append(write_data)
            final_result.append(csv_result)
        return final_result



from PyQt5.QtWidgets import QDialog, QAbstractItemView, QMessageBox
from PyQt5.QtCore import QModelIndex
from zhou_stattool.add_rule_window import Ui_Dialog
from typing import List, Tuple


class AddRuleMainWindow(QDialog):
    def __init__(self, headers, title=None, selected_index=None):
        super(AddRuleMainWindow, self).__init__()
        self.ui = Ui_Dialog()
        self.ui.setupUi(self)
        self.ui.header_widget.setSelectionMode(QAbstractItemView.MultiSelection)
        self.header = headers
        self.title = title
        self.selected_index = selected_index
        self.ui.ok_btn.clicked.connect(self.close_window)
        for item in headers:
            self.ui.header_widget.addItem(item)
        if title and selected_index:
            self.ui.lineEdit.setText(title)
            for index in selected_index:
                item = self.ui.header_widget.item(index)
                item.setSelected(True)

    def close_window(self):
        if self.title and self.selected_index and (not self.ui.lineEdit.text() or not self.ui.header_widget.selectedIndexes()):
            QMessageBox.critical(self, '错误', '请输入修正后的规则名并选择对应项')
        else:
            self.done(QDialog.Accepted)
            self.close()

    def get_result(self) -> Tuple[str, List[QModelIndex]]:
        return self.ui.lineEdit.text(), self.ui.header_widget.selectedIndexes()


import sys
from PyQt5.QtWidgets import QMainWindow, QApplication
from zhou_stattool.mainwindow import Ui_Dialog
from zhou_stattool.roomdata_window_main import RoomdataMainWindow


class AppMainWindow(QMainWindow):
    def __init__(self):
        super(AppMainWindow, self).__init__()
        self.ui = Ui_Dialog()
        self.ui.setupUi(self)

        self.ui.pushButton.clicked.connect(self.goto_roomdata_state)
        self.ui.pushButton_2.clicked.connect(self.goto_operateroom_state)

    def goto_roomdata_state(self):
        self.roomdata_window = RoomdataMainWindow()
        self.roomdata_window.show()


    def goto_operateroom_state(self):
        pass


def main():
    app = QApplication(sys.argv)
    window = AppMainWindow()
    window.show()
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(624, 451)
        self.pushButton = QtWidgets.QPushButton(Dialog)
        self.pushButton.setGeometry(QtCore.QRect(240, 140, 93, 28))
        self.pushButton.setObjectName("pushButton")
        self.pushButton_2 = QtWidgets.QPushButton(Dialog)
        self.pushButton_2.setGeometry(QtCore.QRect(240, 240, 93, 28))
        self.pushButton_2.setObjectName("pushButton_2")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.pushButton.setText(_translate("Dialog", "科室数据"))
        self.pushButton_2.setText(_translate("Dialog", "手术室数据"))




import distutils.spawn
from setuptools import find_packages
from setuptools import setup
import shlex
import subprocess
import sys

install_requires = [
    'PyQt5',
    'openpyxl'
]

if sys.argv[1] == 'release':
    if not distutils.spawn.find_executable('twine'):
        print(
            'Please install twine:\n\n\tpip install twine\n',
            file=sys.stderr,
        )
        sys.exit(1)

    commands = [
        'python setup.py sdist',
        'twine upload dist/zhou_stattool-{:s}.tar.gz'.format('0.0.6'),
    ]
    for cmd in commands:
        subprocess.check_call(shlex.split(cmd))
    sys.exit(0)


def get_long_description():
    with open('README.md', 'r') as f:
        long_description = f.read()
    return long_description


setup(
    name='zhou_stattool',
    version='0.0.6',
    packages=find_packages(),
    description='statistic tool for zhou',
    long_description=get_long_description(),
    long_description_content_type='text/markdown',
    author='Frederic',
    author_email='fk1010098686@outlook.com',
    install_requires=install_requires,
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
    package_data={'zhou_stattool': ['icons/*', ]},
    entry_points={
        'console_scripts': [
            'zhou_stattool=zhou_stattool.app:main',
        ],
    },
)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'roomdata_window.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1185, 1085)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_opened_files = QtWidgets.QLabel(self.centralwidget)
        self.label_opened_files.setObjectName("label_opened_files")
        self.verticalLayout.addWidget(self.label_opened_files)
        self.opened_files_widget = QtWidgets.QListWidget(self.centralwidget)
        self.opened_files_widget.setObjectName("opened_files_widget")
        self.verticalLayout.addWidget(self.opened_files_widget)
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.excel_header_widget = QtWidgets.QListWidget(self.centralwidget)
        self.excel_header_widget.setObjectName("excel_header_widget")
        self.verticalLayout.addWidget(self.excel_header_widget)
        self.horizontalLayout_7.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.open_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.open_rule_btn.setObjectName("open_rule_btn")
        self.horizontalLayout.addWidget(self.open_rule_btn)
        self.save_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.save_rule_btn.setObjectName("save_rule_btn")
        self.horizontalLayout.addWidget(self.save_rule_btn)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.add_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.add_rule_btn.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/icons/plus.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.add_rule_btn.setIcon(icon)
        self.add_rule_btn.setObjectName("add_rule_btn")
        self.horizontalLayout_2.addWidget(self.add_rule_btn)
        self.remove_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.remove_rule_btn.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/minus.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.remove_rule_btn.setIcon(icon1)
        self.remove_rule_btn.setObjectName("remove_rule_btn")
        self.horizontalLayout_2.addWidget(self.remove_rule_btn)
        self.edit_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.edit_rule_btn.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.edit_rule_btn.setIcon(icon2)
        self.edit_rule_btn.setObjectName("edit_rule_btn")
        self.horizontalLayout_2.addWidget(self.edit_rule_btn)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.rules_widget = QtWidgets.QListWidget(self.centralwidget)
        self.rules_widget.setObjectName("rules_widget")
        self.verticalLayout_2.addWidget(self.rules_widget)
        self.horizontalLayout_7.addLayout(self.verticalLayout_2)
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setText("")
        self.label.setPixmap(QtGui.QPixmap(":/icons/icons/arrow.png"))
        self.label.setObjectName("label")
        self.horizontalLayout_7.addWidget(self.label)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.rule_detail_widget = QtWidgets.QListWidget(self.centralwidget)
        self.rule_detail_widget.setObjectName("rule_detail_widget")
        self.verticalLayout_3.addWidget(self.rule_detail_widget)
        self.horizontalLayout_7.addLayout(self.verticalLayout_3)
        self.horizontalLayout_7.setStretch(0, 3)
        self.horizontalLayout_7.setStretch(1, 3)
        self.horizontalLayout_7.setStretch(3, 3)
        self.verticalLayout_7.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.start_process_btn = QtWidgets.QPushButton(self.centralwidget)
        self.start_process_btn.setObjectName("start_process_btn")
        self.horizontalLayout_3.addWidget(self.start_process_btn)
        self.start_date_edit = QtWidgets.QDateEdit(self.centralwidget)
        self.start_date_edit.setObjectName("start_date_edit")
        self.horizontalLayout_3.addWidget(self.start_date_edit)
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setText("")
        self.label_4.setPixmap(QtGui.QPixmap(":/icons/icons/arrow.png"))
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_3.addWidget(self.label_4)
        self.end_date_edit = QtWidgets.QDateEdit(self.centralwidget)
        self.end_date_edit.setObjectName("end_date_edit")
        self.horizontalLayout_3.addWidget(self.end_date_edit)
        self.horizontalLayout_3.setStretch(0, 8)
        self.verticalLayout_7.addLayout(self.horizontalLayout_3)
        self.verticalLayout_7.setStretch(0, 10)
        self.verticalLayout_4.addLayout(self.verticalLayout_7)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1185, 26))
        self.menubar.setObjectName("menubar")
        self.menu = QtWidgets.QMenu(self.menubar)
        self.menu.setObjectName("menu")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionopen_file = QtWidgets.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/open.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionopen_file.setIcon(icon3)
        self.actionopen_file.setObjectName("actionopen_file")
        self.actionopen_dir = QtWidgets.QAction(MainWindow)
        self.actionopen_dir.setIcon(icon3)
        self.actionopen_dir.setObjectName("actionopen_dir")
        self.menu.addAction(self.actionopen_file)
        self.menu.addAction(self.actionopen_dir)
        self.menubar.addAction(self.menu.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.label_opened_files.setText(_translate("MainWindow", "已打开文件"))
        self.label_2.setText(_translate("MainWindow", "表头"))
        self.open_rule_btn.setText(_translate("MainWindow", "打开规则"))
        self.save_rule_btn.setText(_translate("MainWindow", "保存规则文件"))
        self.start_process_btn.setText(_translate("MainWindow", "开始处理"))
        self.menu.setTitle(_translate("MainWindow", "文件"))
        self.actionopen_file.setText(_translate("MainWindow", "打开文件"))
        self.actionopen_dir.setText(_translate("MainWindow", "打开目录"))
import images_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'add_rule_window.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.setWindowModality(QtCore.Qt.WindowModal)
        Dialog.resize(489, 935)
        self.verticalLayoutWidget = QtWidgets.QWidget(Dialog)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(9, 9, 471, 911))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.lineEdit = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout.addWidget(self.lineEdit)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.header_widget = QtWidgets.QListWidget(self.verticalLayoutWidget)
        self.header_widget.setObjectName("header_widget")
        self.verticalLayout.addWidget(self.header_widget)
        self.ok_btn = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.ok_btn.setObjectName("ok_btn")
        self.verticalLayout.addWidget(self.ok_btn)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label.setText(_translate("Dialog", "规则名"))
        self.ok_btn.setText(_translate("Dialog", "确定"))

